summaryrefslogtreecommitdiff
path: root/EmbeddedPkg/Universal/MmcDxe/MmcBlockIo.c
diff options
context:
space:
mode:
authoroliviermartin <oliviermartin@6f19259b-4bc3-4df7-8a09-765794883524>2012-08-02 10:11:29 +0000
committeroliviermartin <oliviermartin@6f19259b-4bc3-4df7-8a09-765794883524>2012-08-02 10:11:29 +0000
commit492e34a59041a04f92958139fee6ee4110a8cbe4 (patch)
treeeeb3c9e09f0c583e9f3912ac7a7380755c0dd6d6 /EmbeddedPkg/Universal/MmcDxe/MmcBlockIo.c
parent7d77584763ad3284971123d55e4f77e6b0bac5b3 (diff)
EmbeddedPkg/MmcDxe: Fixed MmcIdentificationMode()
The condition to check if the card is ready was not correct. Signed-off-by: Olivier Martin <olivier.martin@arm.com> git-svn-id: https://edk2.svn.sourceforge.net/svnroot/edk2/trunk/edk2@13583 6f19259b-4bc3-4df7-8a09-765794883524
Diffstat (limited to 'EmbeddedPkg/Universal/MmcDxe/MmcBlockIo.c')
-rw-r--r--EmbeddedPkg/Universal/MmcDxe/MmcBlockIo.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/EmbeddedPkg/Universal/MmcDxe/MmcBlockIo.c b/EmbeddedPkg/Universal/MmcDxe/MmcBlockIo.c
index 8940f519b..32a85196a 100644
--- a/EmbeddedPkg/Universal/MmcDxe/MmcBlockIo.c
+++ b/EmbeddedPkg/Universal/MmcDxe/MmcBlockIo.c
@@ -1,6 +1,6 @@
/** @file
*
-* Copyright (c) 2011, ARM Limited. All rights reserved.
+* Copyright (c) 2011-2012, ARM Limited. All rights reserved.
*
* This program and the accompanying materials
* are licensed and made available under the terms and conditions of the BSD License
@@ -252,7 +252,7 @@ MmcIdentificationMode (
DEBUG ((EFI_D_ERROR, "Not a SD2.0 Card\n"));
}
// We need to wait for the MMC or SD card is ready => (gCardInfo.OCRData.Busy == 1)
Timeout = MAX_RETRY_COUNT;
while (Timeout > 0) {
// SD Card or MMC Card ? CMD55 indicates to the card that the next command is an application specific command
@@ -287,7 +287,7 @@ MmcIdentificationMode (
}
if (!EFI_ERROR(Status)) {
- if (MmcHostInstance->CardInfo.OCRData.Busy == 0) {
+ if (!MmcHostInstance->CardInfo.OCRData.PowerUp) {
MicroSecondDelay(1);
Timeout--;
} else {
@@ -252,7 +252,7 @@ MmcIdentificationMode (
DEBUG ((EFI_D_ERROR, "Not a SD2.0 Card\n"));
}
- // We need to wait for the MMC or SD card is ready => (gCardInfo.OCRData.Busy == 1)
+ // We need to wait for the MMC or SD card is ready => (gCardInfo.OCRData.PowerUp == 1)
Timeout = MAX_RETRY_COUNT;
while (Timeout > 0) {